﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace UltraColorPicker_HideTabs
{
    public partial class UltraColorPickerPlus : Infragistics.Win.UltraWinEditors.UltraComboEditor, Infragistics.Win.IUIElementCreationFilter
    {
        private Infragistics.Win.UltraWinEditors.UltraPictureBoxControlUIElement ColorElement;
        private Infragistics.Win.UltraWinEditors.UltraPictureBox picturebox = new Infragistics.Win.UltraWinEditors.UltraPictureBox();
        private Infragistics.Win.Misc.UltraPopupControlContainer PopupControl = new Infragistics.Win.Misc.UltraPopupControlContainer();
        private MyTabbedColorPicker ColorPicker = new MyTabbedColorPicker();

        public delegate void ColorPickedHandler(object sender, ColorPickerArgs ca);
        public event ColorPickedHandler ColorPicked;

        public override string Text
        {
            get
            {
                base.Text = string.Empty;
                return string.Empty;
            }
        }

        protected override System.Drawing.Size DefaultSize
        {
            get
            {
                return new Size(50,30);
            }
        }

        public override Infragistics.Win.DropDownStyle DropDownStyle
        {
            get { return Infragistics.Win.DropDownStyle.DropDownList; }
        }

        public Color Color
        {
            get { return ColorPicker.Color; }
        }

        private bool _UseCustom = true;
        [Category("Color Tab Settings")]
        public bool UseCustom
        {
            get { return _UseCustom; }
            set { _UseCustom = value; }
        }

        private bool _UseWeb = true;
        [Category("Color Tab Settings")]
        public bool UseWeb
        {
            get { return _UseWeb; }
            set { _UseWeb = value; }
        }

        private bool _UseSystem = true;
        [Category("Color Tab Settings")]
        public bool UseSystem
        {
            get { return _UseSystem; }
            set { _UseSystem = value; }
        }

        public UltraColorPickerPlus()
        {
            InitializeComponent();

            this.CreationFilter = this;
            this.DropDownStyle = Infragistics.Win.DropDownStyle.DropDownList;
        }

        private void coloreditor_ColorChanged(object sender, EventArgs e)
        {
            PopupControl.Close();
            this.picturebox.BackColor = ColorPicker.Color;
            ColorPickerArgs cpa = new ColorPickerArgs(ColorPicker.Color);
            ColorPicked(this, cpa);
        }

        protected override void OnBeforeDropDown(CancelEventArgs args)
        {
            ColorPicker = new MyTabbedColorPicker(_UseCustom, _UseWeb, _UseSystem);
            ColorPicker.ColorChanged += new EventHandler(coloreditor_ColorChanged);
            PopupControl.PopupControl = ColorPicker;
            PopupControl.Show();
            args.Cancel = true;
            base.OnBeforeDropDown(args);
        }

        public void AfterCreateChildElements(Infragistics.Win.UIElement parent)
        {
            if (parent is Infragistics.Win.UltraWinEditors.UltraComboEditorUIElement)
            {
                ColorElement = new Infragistics.Win.UltraWinEditors.UltraPictureBoxControlUIElement(picturebox);
                picturebox.BorderStyle = Infragistics.Win.UIElementBorderStyle.Solid;

                Rectangle ColorRect = parent.RectInsideBorders;
                ColorRect.Height = 16;
                ColorRect.Width = 16;
                ColorRect.X = 3;
                ColorRect.Y = 3;
                ColorElement.Rect = ColorRect;

                parent.ChildElements.Add(ColorElement);
            }
        }

        public bool BeforeCreateChildElements(Infragistics.Win.UIElement parent)
        {
            return false;
        }
    }

    public partial class MyTabbedColorPicker : Infragistics.Win.TabbedColorPicker
    {
        private bool UseCustom = true, UseWeb = true, UseSystem = true;

        public MyTabbedColorPicker() { }

        public MyTabbedColorPicker(bool usecustom, bool useweb, bool usesystem)
        {
            UseCustom = usecustom;
            UseWeb = useweb;
            UseSystem = usesystem;
        }

        protected override void OnLoad(EventArgs e)
        {
            for (int passes = 0; passes < 3; passes++)
            {
                TabControl tabControl = (TabControl)this.Controls[0];

                foreach (Control tab in tabControl.Controls)
                {
                    if (tab is TabPage)
                    {
                        switch (((TabPage)tab).Text)
                        {
                            case "Custom":
                                if (!UseCustom)
                                    tabControl.TabPages.Remove((TabPage)tab);
                                break;
                            case "Web":
                                if (!UseWeb)
                                    tabControl.TabPages.Remove((TabPage)tab);
                                break;
                            case "System":
                                if (!UseSystem)
                                    tabControl.TabPages.Remove((TabPage)tab);
                                break;
                        }
                    }
                }
            }

            base.OnLoad(e);
        }
    }

    public class ColorPickerArgs : System.EventArgs
    {

        private Color Color;

        public ColorPickerArgs(Color c)
        {
            this.Color = c;
        }

        public Color ColorPicked
        {
            get { return Color; }
        }
    }
}
